@@ -11,7 +11,7 @@ except ImportError:
     # NOTE - could use subprocess to get from git?
     __rev__ = "local"
 
-__version__ = "0.7.4"
+__version__ = "0.8.1"
 
 TEST_ENV: bool = "DP_TEST_ENV" in os.environ
 
@@ -34,10 +34,12 @@ from .client.api import (
     Table,
     Variable,
     by_datapane,
+    login,
+    logout,
     on_datapane,
+    ping,
 )
 from .client.config import init
-
 from .common.dp_types import DPMode, set_dp_mode, get_dp_mode
 
 script_name = sys.argv[0]
@@ -55,3 +57,7 @@ else:
 # only init fully in library-mode, as framework and app init explicitly
 if get_dp_mode() == DPMode.LIBRARY:
     init()
+    # parse any command0line params
+    from .client.utils import parse_command_line
+
+    parse_command_line()
