@@ -3,5 +3,7 @@
 from .dp_object import BEObjectRef, Blob, Run, Schedule, Script, Variable
 from .report import Blocks, File, Markdown, Plot, Report, Table
 from .runtime import Params, Result, by_datapane, on_datapane, _reset_runtime, _report
-from .common import HTTPError, IncompatibleVersionException, Resource, check_login
+from .common import HTTPError, Resource
+from .user import login, logout, ping
+from ..utils import IncompatibleVersionException
 from ..config import init
