@@ -6,9 +6,8 @@ import typing as t
 import uuid
 from contextlib import contextmanager
 from distutils.dir_util import copy_tree
-from distutils.util import strtobool
 from pathlib import Path
-from typing import Dict, Iterator, List, Optional, Tuple
+from typing import Dict, List, Optional, Tuple
 
 import click
 import click_spinner
@@ -18,12 +17,13 @@ from requests import HTTPError
 from tabulate import tabulate
 
 from datapane import __rev__, __version__
-from datapane.common import JDict, SDict, _setup_dp_logging, log
+from datapane.common import SDict, _setup_dp_logging, log
 
 from . import api
 from . import config as c
-from . import scripts
+from . import scripts, utils
 from .scripts import config as sc
+from .utils import failure_msg, process_cmd_param_vals, success_msg
 
 EXTRA_OUT: bool = False
 
@@ -52,20 +52,6 @@ class DPContext:
     env: str
 
 
-def success_msg(msg: str):
-    click.secho(msg, fg="green")
-
-
-def failure_msg(msg: str, do_exit: bool = False):
-    click.secho(msg, fg="red")
-    if do_exit:
-        ctx: click.Context = click.get_current_context(silent=True)
-        if ctx:
-            ctx.exit(2)
-        else:
-            exit(2)
-
-
 @contextmanager
 def api_error_handler(err_msg: str):
     try:
@@ -87,11 +73,11 @@ def print_table(xs: t.Iterable[SDict], obj_name: str, showindex: bool = True) ->
     print(tabulate(xs, headers="keys", showindex=showindex))
 
 
-class CatchIncompatibleVersion(click.Group):
+class GlobalCommandHandler(click.Group):
     def __call__(self, *args, **kwargs):
         try:
             return self.main(*args, **kwargs)
-        except api.IncompatibleVersionException as exc:
+        except utils.IncompatibleVersionException as exc:
             if EXTRA_OUT:
                 log.exception(exc)
             failure_msg(str(exc))
@@ -107,9 +93,12 @@ class CatchIncompatibleVersion(click.Group):
 
 ###############################################################################
 # Main
-@click.group(cls=CatchIncompatibleVersion)
+@click.group(cls=GlobalCommandHandler)
 @click.option(
-    "-v", "--verbose", count=True, help="Increase logging verbosity - can add multiple times"
+    "-v",
+    "--verbose",
+    count=True,
+    help="Increase logging verbosity - can add multiple times",
 )
 @click.option("--env", default=c.DEFAULT_ENV, help="Alternate config environment to use.")
 @click.version_option(version=f"{__version__} ({__rev__})")
@@ -126,41 +115,27 @@ def cli(ctx, verbose: int, env: str):
 # Auth
 @cli.command()
 @click.option("--token", prompt="Your API Token", help="API Token to the Datapane server.")
-@click.option("--server", default="https://datapane.com", help="Datapane API Server URL.")
+@click.option("--server", default=c.DEFAULT_SERVER, help="Datapane API Server URL.")
 @click.pass_obj
 def login(obj: DPContext, token, server):
     """Login to a server with the given API token."""
-    config = c.Config(server=server, token=token)
-    r = api.check_login(config=config, cli_login=True)
-
-    # update config with valid values
-    with c.update_config(obj.env) as x:
-        x["server"] = server
-        x["token"] = token
-
+    api.login(token, server, env=obj.env, cli_login=True)
     # click.launch(f"{server}/settings/")
-    success_msg(f"Logged in to {server} as {r.username}")
 
 
 @cli.command()
 @click.pass_obj
 def logout(obj: DPContext):
     """Logout from the server and reset the API token in the config file."""
-    with c.update_config(obj.env) as x:
-        x["server"] = c.DEFAULT_SERVER
-        x["token"] = c.DEFAULT_TOKEN
-
-    success_msg(f"Logged out from {c.config.server}")
+    api.logout(obj.env)
 
 
 @cli.command()
 def ping():
     """Check can connect to the server."""
     try:
-        r = api.check_login()
-        success_msg(f"Connected to {c.config.server} as {r.username}")
+        api.ping()
     except HTTPError as e:
-        failure_msg(f"Couldn't successfully connect to {c.config.server}, check your login details")
         log.error(e)
 
 
@@ -203,8 +178,8 @@ def delete(name: str):
     success_msg(f"Deleted Blob {name}")
 
 
-@blob.command()
-def list():
+@blob.command("list")
+def blob_list():
     """List blobs"""
     print_table(api.Blob.list(), "Blobs")
 
@@ -217,10 +192,8 @@ def script():
     ...
 
 
-@script.command(name="init")
-@click.argument("name", default=lambda: os.path.basename(os.getcwd()))
-def script_init(name: str):
-    """Initialise a new script project"""
+def write_templates(scaffold_name: str, context: SDict):
+    """Write templates for the given local scaffold (TODO - support git repos)"""
     # NOTE - only supports single hierarchy project dirs
     env = Environment(loader=FileSystemLoader("."))
 
@@ -230,22 +203,29 @@ def script_init(name: str):
 
     # copy the scaffolds into the service
     def copy_scaffold() -> List[Path]:
-        dir_path = ir.files("datapane.resources") / "scaffold"
+        dir_path = ir.files("datapane.resources.templates") / scaffold_name
         copy_tree(dir_path, ".")
         return [Path(x.name) for x in dir_path.iterdir()]
 
+    # run the scripts
+    files = copy_scaffold()
+    for f in files:
+        if f.exists() and f.is_file():
+            render_file(f, context=context)
+
+
+@script.command(name="init")
+@click.argument("name", default=lambda: os.path.basename(os.getcwd()))
+def script_init(name: str):
+    """Initialise a new script project"""
     if sc.DATAPANE_YAML.exists():
-        raise ValueError("Found existing project, cancelling")
+        failure_msg("Found existing project, cancelling", do_exit=True)
 
     name = name.replace("-", "_")
     sc.validate_name(name)
-    files = copy_scaffold()
-
-    # run the scripts
     _context = dict(name=name)
-    for f in files:
-        if f.exists() and f.is_file():
-            render_file(f, context=_context)
+
+    write_templates("script", _context)
     success_msg(f"Created dp_script.py for project '{name}', edit as needed and upload")
 
 
@@ -300,42 +280,12 @@ def delete(name: str):
     success_msg(f"Deleted Script {name}")
 
 
-@script.command()
-def list():
+@script.command("list")
+def script_list():
     """List Scripts"""
     print_table(api.Script.list(), "Scripts")
 
 
-def process_cmd_param_vals(params: Tuple[str, ...]) -> JDict:
-    """Convert a list of k=v to a typed JSON dict"""
-
-    def convert_param_val(x: str) -> t.Union[int, float, str, bool]:
-        # TODO - this can be optimised / cleaned-up
-        try:
-            return int(x)
-        except ValueError:
-            try:
-                return float(x)
-            except ValueError:
-                try:
-                    return bool(strtobool(x))
-                except ValueError:
-                    return x
-
-    def split_param(xs: Tuple[str]) -> Iterator[t.Tuple[str, str]]:
-        err_msg = "'{}', should be name=value"
-        for x in xs:
-            try:
-                k, v = x.split("=", maxsplit=1)
-            except ValueError:
-                raise click.BadParameter(err_msg.format(x))
-            if not k or not v:
-                raise click.BadParameter(err_msg.format(x))
-            yield (k, v)
-
-    return {k: convert_param_val(v) for (k, v) in split_param(params)}
-
-
 @script.command()
 @click.option("--parameter", "-p", multiple=True)
 @click.option("--cache/--disable-cache", default=True)
@@ -343,7 +293,14 @@ def process_cmd_param_vals(params: Tuple[str, ...]) -> JDict:
 @click.option("--owner")
 @click.option("--show-output", is_flag=True, default=False, help="Display the run output")
 @click.argument("name")
-def run(name: str, parameter: Tuple[str], cache: bool, wait: bool, owner: str, show_output: bool):
+def run(
+    name: str,
+    parameter: Tuple[str],
+    cache: bool,
+    wait: bool,
+    owner: str,
+    show_output: bool,
+):
     """Run a report"""
     params = process_cmd_param_vals(parameter)
     log.info(f"Running script with parameters {params}")
@@ -379,17 +336,39 @@ def report():
     ...
 
 
-@report.command()
-@click.argument("name")
-@click.argument("files", type=click.Path(), nargs=-1, required=True)
-@click.option("--headline", default="Untitled")
-@click.option("--visibility", type=click.Choice(["PUBLIC", "ORG", "PRIVATE"]))
-def create(files: Tuple[str], name: str, headline: str, visibility: str):
-    """Create a Report from the provided FILES"""
-    blocks = [api.Asset.upload_file(file=Path(f)) for f in files]
-    r = api.Report(*blocks)
-    r.publish(name=name, headline=headline, visibility=visibility)
-    success_msg(f"Created Report {r.web_url}")
+# NOTE - CLI Report creation disabled for now until we have a replacement for Asset
+# @report.command()
+# @click.argument("name")
+# @click.argument("files", type=click.Path(), nargs=-1, required=True)
+# @click.option("--visibility", type=click.Choice(["PUBLIC", "ORG", "PRIVATE"]))
+# def create(files: Tuple[str], name: str, visibility: str):
+#     """Create a Report from the provided FILES"""
+#     blocks = [api.Asset.upload_file(file=Path(f)) for f in files]
+#     r = api.Report(*blocks)
+#     r.publish(name=name, visibility=visibility)
+#     success_msg(f"Created Report {r.web_url}")
+
+
+@report.command(name="init")
+@click.argument("name", default=lambda: os.path.basename(os.getcwd()))
+@click.option("--format", type=click.Choice(["notebook", "script"]), default="notebook")
+def report_init(name: str, format: str):
+    """Initialise a new report"""
+
+    if format == "notebook":
+        template = "report_ipynb"
+    else:
+        template = "report_py"
+
+    if len(list(Path(".").glob("dp_report.*"))):
+        failure_msg("Found existing project, cancelling", do_exit=True)
+
+    name = name.replace("-", "_")
+    sc.validate_name(name)
+    _context = dict(name=name)
+
+    write_templates(template, _context)
+    success_msg("Created sample report `dp_report`, edit as needed and run")
 
 
 @report.command()
@@ -400,8 +379,8 @@ def delete(name: str):
     success_msg(f"Deleted Report {name}")
 
 
-@report.command()
-def list():
+@report.command("list")
+def report_list():
     """List Reports"""
     print_table(api.Report.list(), "Reports")
 
@@ -444,8 +423,8 @@ def create(name: str, value: str, visibility: str):
     success_msg(f"Created variable: {name}")
 
 
-@variable.command()
-def list():
+@variable.command("list")
+def variable_list():
     """List all variables"""
     print_table(api.Variable.list(), "Variables")
 
@@ -461,7 +440,10 @@ def get(name, owner, version, show):
     if show:
         print(str(res.value).strip())
     else:
-        print_table([{"name": name, "value": res.value, "visibility": res.visibility}], "Variable")
+        print_table(
+            [{"name": name, "value": res.value, "visibility": res.visibility}],
+            "Variable",
+        )
 
 
 @variable.command()
@@ -482,19 +464,23 @@ def schedule():
 
 @schedule.command()
 @click.option("--parameter", "-p", multiple=True)
-@click.argument("script", required=True)
+@click.argument("name", required=True)
 @click.argument("cron", required=True)
-def create(script: str, cron: str, parameter: Tuple[str]):
+@click.option("--version")
+@click.option("--owner")
+def create(name: str, cron: str, parameter: Tuple[str], owner: str, version: str):
     """
     Create a schedule
 
-    SCRIPT: ID/URL of the Script to run
+    NAME: Name of the Script to run
     CRON: crontab representing the schedule interval
     PARAMETERS: key/value list of parameters to use when running the script on schedule
+    [OWNER]: Script owner
+    [VERSION]: Script version
     """
     params = process_cmd_param_vals(parameter)
     log.info(f"Adding schedule with parameters {params}")
-    script_obj = api.Script.by_id(script)
+    script_obj = api.Script.get(name, owner=owner, version=version)
     schedule_obj = api.Schedule.create(script_obj, cron, params)
     success_msg(f"Created schedule: {schedule_obj.id} ({schedule_obj.url})")
 
@@ -522,8 +508,8 @@ def update(id: str, cron: str, parameter: Tuple[str]):
     success_msg(f"Updated schedule: {schedule_obj.id} ({schedule_obj.url})")
 
 
-@schedule.command()
-def list():
+@schedule.command("list")
+def schedule_list():
     """List all schedules"""
     print_table(api.Schedule.list(), "Schedules", showindex=False)
 
